@@ -626,10 +626,8 @@ class XTream:
                             if not skip_stream:
                                 # Some channels have no group,
                                 # so let's add them to the catch all group
-                                if stream_channel["category_id"] is None:
+                                if not stream_channel["category_id"]: 
                                     stream_channel["category_id"] = "9999"
-                                elif stream_channel["category_id"] != "1":
-                                    pass
 
                                 # Find the first occurence of the group that the
                                 # Channel or Stream is pointing to
